==> haskell-time-compat-1.9.2.2-15-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-time-compat.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: time-compat
version: 1.9.2.2
id: time-compat-1.9.2.2-HRXEB8vd1ksixV8fkdOMJ
key: time-compat-1.9.2.2-HRXEB8vd1ksixV8fkdOMJ
license: BSD-3-Clause
maintainer: Oleg Grenrus <oleg.grenrus@iki.fi>
author: Ashley Yakeley
homepage: https://github.com/phadej/time-compat
synopsis: Compatibility package for time
description:
    This packages tries to compat as much of @time@ features as possible.
    .
    /TODO:/
    .
    * Difference type @ParseTime@ and @FormatTime@ instances are missing.
    .
    * Formatting varies depending on underlying @time@ version
    .
    * @dayFractionToTimeOfDay@ on extreme values
category: Time, Compatibility
abi: 5f444f2a4e0970b9ebe63744262d0461
exposed: True
exposed-modules:
    Data.Time.Calendar.Compat Data.Time.Calendar.Easter.Compat
    Data.Time.Calendar.Julian.Compat Data.Time.Calendar.MonthDay.Compat
    Data.Time.Calendar.OrdinalDate.Compat
    Data.Time.Calendar.WeekDate.Compat Data.Time.Clock.Compat
    Data.Time.Clock.POSIX.Compat Data.Time.Clock.System.Compat
    Data.Time.Clock.TAI.Compat Data.Time.Compat Data.Time.Format.Compat
    Data.Time.Format.ISO8601.Compat Data.Time.LocalTime.Compat
hidden-modules: Data.Format Data.Time.Calendar.Private
                Data.Time.Orphans
import-dirs: /usr/lib/ghc-8.6.5/site-local/time-compat-1.9.2.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/time-compat-1.9.2.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/time-compat-1.9.2.2
hs-libraries: HStime-compat-1.9.2.2-HRXEB8vd1ksixV8fkdOMJ
depends:
    base-4.12.0.0 base-orphans-0.8.1-1ipEgB2SRGR7acY6peEbpr
    deepseq-1.4.4.0 time-1.8.0.2
haddock-interfaces: /usr/share/doc/haskell-time-compat/html/time-compat.haddock
haddock-html: /usr/share/doc/haskell-time-compat/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-time-compat-1.9.2.2-16-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-time-compat.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: time-compat
version: 1.9.2.2
id: time-compat-1.9.2.2-CnzOLNt25EK1IT6xdCRyZq
key: time-compat-1.9.2.2-CnzOLNt25EK1IT6xdCRyZq
license: BSD-3-Clause
maintainer: Oleg Grenrus <oleg.grenrus@iki.fi>
author: Ashley Yakeley
homepage: https://github.com/phadej/time-compat
synopsis: Compatibility package for time
description:
    This packages tries to compat as much of @time@ features as possible.
    .
    /TODO:/
    .
    * Difference type @ParseTime@ and @FormatTime@ instances are missing.
    .
    * Formatting varies depending on underlying @time@ version
    .
    * @dayFractionToTimeOfDay@ on extreme values
category: Time, Compatibility
abi: 424de2638f62220fb29ec2e270657864
exposed: True
exposed-modules:
    Data.Time.Calendar.Compat Data.Time.Calendar.Easter.Compat
    Data.Time.Calendar.Julian.Compat Data.Time.Calendar.MonthDay.Compat
    Data.Time.Calendar.OrdinalDate.Compat
    Data.Time.Calendar.WeekDate.Compat Data.Time.Clock.Compat
    Data.Time.Clock.POSIX.Compat Data.Time.Clock.System.Compat
    Data.Time.Clock.TAI.Compat Data.Time.Compat Data.Time.Format.Compat
    Data.Time.Format.ISO8601.Compat Data.Time.LocalTime.Compat
hidden-modules: Data.Format Data.Time.Calendar.Private
                Data.Time.Orphans
import-dirs: /usr/lib/ghc-8.6.5/site-local/time-compat-1.9.2.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/time-compat-1.9.2.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/time-compat-1.9.2.2
hs-libraries: HStime-compat-1.9.2.2-CnzOLNt25EK1IT6xdCRyZq
depends:
    base-4.12.0.0 base-orphans-0.8.1-HeyTAcy4PKhDcGhjvJwDzq
    deepseq-1.4.4.0 time-1.8.0.2
haddock-interfaces: /usr/share/doc/haskell-time-compat/html/time-compat.haddock
haddock-html: /usr/share/doc/haskell-time-compat/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
